package TestIdealoProductsExportDriver;
use strict;

use DE_EPAGES::Core::API::Script qw ( RunScript );
use Test::More;
use DE_EPAGES::Idealo::API::CSV::IdealoProductsExportDriver;
use Test::MockObject;

sub Main {
    testgetPriceForPayment();
    done_testing();
}

sub testgetPriceForPayment {

    my $TestName = (caller(0))[3];
    my $mySelf = _getSelfObject('GBP');

    my $paymentMethod = _getPaymentMethodObject('');
    my $result = DE_EPAGES::Idealo::API::CSV::IdealoProductsExportDriver::getPriceForPayment($mySelf,$paymentMethod,10);
    is($result, 0,"$TestName - test behavoir of getPriceForPayment with undef discount mode - 0");

    $paymentMethod = _getPaymentMethodObject(0);
    $result = DE_EPAGES::Idealo::API::CSV::IdealoProductsExportDriver::getPriceForPayment($mySelf,$paymentMethod,10);
    is($result, 0,"$TestName - test behavoir of getPriceForPayment without discount or fee - 0");

    $paymentMethod = _getPaymentMethodObject(1);
    $result = DE_EPAGES::Idealo::API::CSV::IdealoProductsExportDriver::getPriceForPayment($mySelf,$paymentMethod,10);
    is($result, 0,"$TestName - test behavoir of getPriceForPayment with percentage discount - 0");

    $paymentMethod = _getPaymentMethodObject(2);
    $result = DE_EPAGES::Idealo::API::CSV::IdealoProductsExportDriver::getPriceForPayment($mySelf,$paymentMethod,10);
    is($result, 0,"$TestName - test behavoir of getPriceForPayment with fix discount value - 0");

    $paymentMethod = _getPaymentMethodObject(3);
    $result = DE_EPAGES::Idealo::API::CSV::IdealoProductsExportDriver::getPriceForPayment($mySelf,$paymentMethod,666);
    is($result, 66.6,"$TestName - test behavoir of getPriceForPayment with percentage of fee - 66.6");

    $paymentMethod = _getPaymentMethodObject(4);
    $result = DE_EPAGES::Idealo::API::CSV::IdealoProductsExportDriver::getPriceForPayment($mySelf,$paymentMethod,10);
    is($result, 42,"$TestName - test behavoir of getPriceForPayment with fix fee (GBP)- 42");

    $mySelf = _getSelfObject('EUR');
    $paymentMethod = _getPaymentMethodObject(4);
    $result = DE_EPAGES::Idealo::API::CSV::IdealoProductsExportDriver::getPriceForPayment($mySelf,$paymentMethod,10);
    is($result, 23,"$TestName - test behavoir of getPriceForPayment with fix fee (EUR)- 23");

    $paymentMethod = _getPaymentMethodObject(5);
    $result = DE_EPAGES::Idealo::API::CSV::IdealoProductsExportDriver::getPriceForPayment($mySelf,$paymentMethod,10);
    is($result, 0,"$TestName - test behavoir of getPriceForPayment with to high CashDiscountMode - 0");
}

sub _getPaymentMethodObject {
    my ($DiscountMode) = @_;
    my $paymentMethodObject = Test::MockObject->new();
    $paymentMethodObject->mock('get', sub {
            my $self = shift;
            my ($ArgumentName) = @_;
            if ($ArgumentName eq 'CashDiscountMode'){
                return $DiscountMode;
            }
            if ($ArgumentName eq 'CashDiscount'){
                return 10;
            }
            if ($ArgumentName eq 'Discounts'){
                return [
                    { CurrencyID=>'EUR', PriceValue=>23 },
                    { CurrencyID=>'GBP', PriceValue=>42 }
                ];
            }
    });
    return $paymentMethodObject;
}

sub _getSelfObject {
    my ($currencyID) = @_;
    my $selfObject = Test::MockObject->new();
    $selfObject->mock('currencyID', sub {
        return $currencyID;
    });
    return $selfObject;
}

RunScript( Sub => \&Main );